"""
Module for encoding from text to code.
"""

morse_to_letter = {'.-': 'A', '-...': 'B', '-.-.': 'C', '-..': 'D', '.': 'E',
                   '..-.': 'F', '--.': 'G', '....': 'H', '..': 'I', '.---': 'J',
                   '-.-': 'K', '.-..': 'L', '--': 'M', '-.': 'N', '---': 'O',
                   '.--.': 'P', '--.-': 'Q', '.-.': 'R', '...': 'S', '-': 'T',
                   '..-': 'U', '...-': 'V', '.--': 'W', '-..-': 'X', '-.--': 'Y',
                   '--..': 'Z'}


def convert_code_to_sentence(user_input):
    """
    Method converts code to the text
    :param user_input: Code from user
    :return: decoded text
    """
    letters_in_morse = convert_code_to_morse(user_input)
    return convert_morse_to_letters(letters_in_morse)


def convert_code_to_morse(code):
    """
    Method converts whole code to the morse code
    :param code: code
    :return: morse of the code
    """
    coded_letters = code.split('0')
    letters = []
    for coded_letter in coded_letters:
        letters.append(convert_one_letter(coded_letter))
    return letters


def convert_morse_to_letters(morse_code):
    """
    Method converts morse to letters
    :param morse_code: morse code of letters
    :return: decoded text
    """
    result = ""
    for letter in morse_code:
        if len(letter) > 0:
            result += morse_to_letter.get(letter)
    return result


def convert_one_letter(letter):
    """
    Method converts code to the morse code of one letter, throws error while non number input
    :param letter: coded letter
    :return: morse code of letter
    """
    result = ""
    for char in letter:
        if char.isdigit():
            digit = int(char)
            if digit % 2 == 0:
                result = result + "."
            else:
                result = result + "-"
        else:
            raise ValueError("Input contains non digit chars")
    return result


def start_decoding():
    """
    Method for communication with the user
    """
    user_input = input("Enter code: ")
    print("Decoded sentence: {}".format(convert_code_to_sentence(user_input)))
    input("Press enter to continue...")
