"""
Module for encoding from text to code.
"""

import random

letter_to_morse = {"A": ".-", "B": "-...", "C": "-.-.", "D": "-..", "E": ".",
                   "F": "..-.", "G": "--.", "H": "....", "I": "..", "J": ".---",
                   "K": "-.-", "L": ".-..", "M": "--", "N": "-.", "O": "---",
                   "P": ".--.", "Q": "--.-", "R": ".-.", "S": "...", "T": "-",
                   "U": "..-", "V": "...-", "W": ".--", "X": "-..-", "Y": "-.--",
                   "Z": "--.."}


def generate_even_number():
    """
    Method for generating random even number.
    :return: Random even number.
    """
    random_number = random.randint(1, 8)
    if random_number % 2 != 0:
        random_number += 1
    return random_number


def generate_odd_number():
    """
    Method for generating random odd number.
    :return: Random odd number.
    """
    random_number = random.randint(0, 9)
    if random_number % 2 == 0:
        random_number += 1
    return random_number


def convert_letter_to_morse(letter):
    """
    Method converts letter to the morse.
    :param letter: letter form the text.
    :return: morse of the letter, "" in case of char which is not in dictionary
    """
    if str.upper(letter) in letter_to_morse:
        return letter_to_morse.get(str.upper(letter))
    return ""


def convert_morse_to_code(morse):
    """
    Method converts morse code into the code (. = even number, - = odd number, separator = 0)
    :param morse: morse code of letter
    :return: coded letter
    """
    code = ""
    for char in morse:
        if char == '.':
            code += str(generate_even_number())
        elif char == '-':
            code += str(generate_odd_number())
    return code


def convert_text_to_code(text_to_encoded):
    """
    Method converts text to code
    :param text_to_encoded: text which will be encoded
    :return: coded text
    """
    code = ""
    for letter in text_to_encoded:
        code += convert_morse_to_code(convert_letter_to_morse(letter))
        code += '0'
    return code


def start_encoding():
    """
    Method for communication with the user
    """
    user_input = input("Enter sentence to encode: ")
    print("Encoded sentence: {}".format(convert_text_to_code(user_input)))
    input("Press enter to continue...")
